
# Type: has stressor


the process or entity that the receptor is being exposed to

URI: [biolink:has_stressor](https://w3id.org/biolink/vocab/has_stressor)


## Domain and Range

[ExposureEvent](ExposureEvent.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [ChemicalExposure](ChemicalExposure.md)
 * [DrugExposure](DrugExposure.md)
 * [ExposureEvent](ExposureEvent.md)
 * [Treatment](Treatment.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | has stimulus |
| **Mappings:** | | ExO:0000000 |

